==> worlds_pokemon_crystal-5.0.4.tar.gz: worlds_pokemon_crystal-5.0.4/src/worlds/pokemon_crystal/docs/pl_Pokemon Crystal.md <==
# Pokémon Crystal

## Gdzie jest strona opcji?

Możesz zapoznać się ze wszystkimi opcjami i wygenerować plik YAML [tutaj](../player-options).

## Jak losowość wpływa na tę grę?

W podstawowej wersji gry wprowadzono pewne zmiany związane z losowością:

- Walka trenerów na trasie 30 kończy się zaraz po rozmowie z panem Pokémonem, pomijając wizytę u profesora Elm.
- Dyrektor zawsze przebywa w podziemnym magazynie, nawet gdy wieża radiowa nie jest zajęta.
- Drzwi na kartę w domu towarowym Goldenrod na poziomie B1F otwierają się za pomocą karty znajdującej się w plecaku.
- Kontrole oparte na czasie, takie jak rodzeństwo z dnia tygodnia i facet na dachu rezydencji Celadon, są zawsze dostępne.
- Ukryte przedmioty pod Freidą i Wesleyem zostały przeniesione o jedną płytkę, aby pozostały dostępne.
- Statek między Olivine a Vermilion jest zawsze obecny w grach innych niż Johto, nawet przed wejściem do Hall of Fame,
  i można nim pływać za pomocą biletu S.S.
- Pociąg magnetyczny między Goldenrod a Saffron jest dostępny do jazdy z przepustką przed przywróceniem zasilania w Kanto
- Misty jest zawsze w Cerulean Gym
- Półka na Route 45 została przesunięta, aby wszystkie przedmioty i trenerzy byli dostępni w 2 przejściach
- W przypadku opcji, które to umożliwiają, odznaki Kanto odpowiadają następującym HM:
    - HM01 Cut - Cascade Badge
    - HM02 Fly - Thunder Badge
    - HM03 Surf - Soul Badge
    - HM04 Strength - Rainbow Badge
    - HM05 Flash - Boulder Badge
    - HM06 Whirlpool - Odznaka Volcano
    - HM07 Waterfall - Odznaka Earth
- TM02 i TM08 będą zawsze odpowiednio Headbutt i Rock Smash i zawsze będą wielokrotnego użytku.
- Ewolucje wymiany zostały zmienione, aby były możliwe w trybie solo:
    - Zwykłe ewolucje wymiany następują teraz na poziomie 37.
    - Ewolucje wymiany przedmiotów ewoluują, gdy użyje się na nich przedmiotu ewolucji, tak jak w przypadku kamienia ewolucji.
- Eevee ewoluuje w Espeona i Umbreona odpowiednio za pomocą kamienia słońca i kamienia księżyca.
- Ewolucje szczęścia są logicznie powiązane z dostępem do podziemi Goldenrod lub Pallet Town. Młodszy brat o krótkiej fryzurze i Daisy maksymalizują poziom szczęścia pokemona i są zawsze dostępni.
- Po zdobyciu Clear Bell można wejść na 1. piętro Tin Tower.
- Tin Tower 2F+ jest dostępna po spełnieniu powyższego warunku i posiadaniu Rainbow Wing. Oba są przedmiotami w multiworld.
- Eusine przekaże graczowi wiadomość Eon Mail, jeśli porozmawia z nim na 1. piętrze wieży Tin Tower po zobaczeniu Suicune w świecie gry we wszystkich możliwych lokalizacjach, które można odwiedzać w dowolnej kolejności
- Wydarzenie Celebi można aktywować, przekazując Kurtowi przedmiot wieloświatowy GS-Ball po ukończeniu Slowpoke Well i pokonaniu rywala w Azalea.
- Wydarzenie, które zazwyczaj zapewnia GS Ball w Goldenrod Pokécenter 1F, aktywuje się po zdobyciu tytułu mistrza.
- Dostęp do komnaty z przedmiotami Ruins of Alph Ho-Oh można uzyskać, posiadając skrzydło Rainbow Wing
- Do 2F wszystkich centrów Pokémon dodano sklep, którego asortyment można dostosować za pomocą opcji `build_a_mart`.
 Sklep zawsze będzie sprzedawał Poké Balls i Escape Ropes
- Na drugim piętrze wszystkich centrów Pokémon dodano postać NPC, która pozwala walczyć z losowym dzikim Pokémonem. Walka ta zapewnia
  pieniądze i doświadczenie, ale nie zapewnia wpisów do Pokédexu i nie można złapać pokemona.

## Jakie przedmioty i lokalizacje są losowane?

Domyślnie losowane są przedmioty z kul przedmiotów i przedmioty przekazywane przez NPC.
Odznaki mogą być standardowe, przetasowane lub losowe. Pokégear i jego moduły kart mogą być standardowe lub losowe.
Jeśli włączony jest tryb Johto Only, przedmioty w Kanto nie będą losowane, a Kanto będzie niedostępne.

Istnieją opcje umożliwiające dodanie większej liczby przedmiotów do puli:

- Losowe ukryte przedmioty: dodaje ukryte przedmioty do puli
- Losowe drzewa jagodowe: dodaje przedmioty z drzew jagodowych do puli
- Szaleństwo trenerów: dodaje do puli nagrodę za pokonanie trenerów
- Dexsanity: wpis Pokémona w Dexie może zawierać czek. Jest to powiązane z konkretnym Pokémonem
- Dexcountsanity: pewna liczba wpisów w Dexie zawiera czeki. Nie jest to powiązane z konkretnym Pokémonem, ale z całkowitą liczbą
- Shopsanity: dodaje przedmioty ze sklepu do puli

## Jakie inne zmiany wprowadzono do gry?

Wprowadzono wiele dodatkowych zmian poprawiających komfort gry:

- Do menu opcji w grze dodano nową opcję szybkości tekstu, Instant.
- Przyciski A i/lub B mogą służyć jako przyciski turbo, umożliwiające przyspieszenie dialogów.
- Gdy sceny bitewne są wyłączone, animacje zmniejszenia HP i zdobycia XP są pomijane
- Opcja Battle Scene jest bardziej szczegółowa, a najszybszy wybór, Speedy, eliminuje prawie wszystkie animacje.
- Możesz przytrzymać przycisk B, aby biec. Dostępna jest również opcja Auto-run, a jeśli jest włączona, przycisk B uniemożliwia bieganie.
- Dodano wiele innych opcji, które znacznie przyspieszają rozgrywkę, w tym: Rods mogą zawsze działać, niezłapane pokemony mogą pojawiać się częściej, trenerzy mogą być ślepi itp.
- Usunięto opóźnienia w menu
- Rower można używać w pomieszczeniach
- Jeśli skończy się repelent, a masz więcej w plecaku, pojawi się monit o użycie kolejnego.
- Tempo wzrostu pokemonów zostało znormalizowane (średnio-szybkie dla pokemonów niebędących legendarnymi, wolne dla pokemonów legendarnych).
- Usunięto system resetowania zegara za pomocą hasła. Zegar można zresetować, naciskając przyciski Down + Select + B na ekranie tytułowym.
- Dodano opcję w grze, dzięki której nie trzeba uczyć się ruchów terenowych. Aby zachować dostępność ruchów Fly, Flash i innych ruchów terenowych, po naciśnięciu przycisku Select w menu Start dostępne jest dodatkowe menu.
- Możesz odnowić wszystkie statyczne wydarzenia, rozmawiając z osobą odpowiedzialną za kapsułę czasu na drugim piętrze dowolnego PokéCenter
- Możesz teleportować się z powrotem do miasta startowego, wybierając opcję „Go Home” w menu głównym przed załadowaniem
  świata gry

## Jak wygląda przedmiot z innego świata w Pokémon Crystal?

Przedmioty z innych światów będą drukować nazwę przedmiotu i nazwę gracza, który go otrzymał, po zebraniu. Ze względu na
ograniczenia tekstu w grze nazwy te są skracane do 16 znaków, a znaki specjalne, których nie ma w
czcionce, są zastępowane znakami zapytania.

## Co się dzieje, gdy gracz otrzymuje przedmiot?

Jeśli opcja „Dźwięk otrzymania przedmiotu” jest włączona, po otrzymaniu przedmiotu zostanie odtworzony efekt dźwiękowy. Aby odróżnić przedmioty związane z postępami w grze od pułapek, odtwarzane są różne dźwięki.

## Czy mogę grać w trybie offline?

Tak, gra nie wymaga połączenia z klientem w przypadku nasion solo. Połączenie jest wymagane tylko do wysyłania i
odbierania przedmiotów. Nie dotyczy to sytuacji, gdy włączona jest opcja `remote_items`.

==> worlds_pokemon_crystal-5.3.4.tar.gz: worlds_pokemon_crystal-5.3.4/src/worlds/pokemon_crystal/docs/pl_Pokemon Crystal.md <==
# Pokémon Crystal

## Gdzie jest strona opcji?

Możesz zapoznać się ze wszystkimi opcjami i wygenerować plik YAML [tutaj](../player-options).

## Jak losowość wpływa na tę grę?

W podstawowej wersji gry wprowadzono pewne zmiany związane z losowością:

- Walka trenerów na trasie 30 kończy się zaraz po rozmowie z panem Pokémonem, pomijając wizytę u profesora Elm.
- Dyrektor zawsze przebywa w podziemnym magazynie, nawet gdy wieża radiowa nie jest zajęta.
- Drzwi na kartę w domu towarowym Goldenrod na poziomie B1F otwierają się za pomocą karty znajdującej się w plecaku.
- Kontrole oparte na czasie, takie jak rodzeństwo z dnia tygodnia i facet na dachu rezydencji Celadon, są zawsze
  dostępne.
- Ukryte przedmioty pod Freidą i Wesleyem zostały przeniesione o jedną płytkę, aby pozostały dostępne.
- Statek między Olivine a Vermilion jest zawsze obecny w grach innych niż Johto, nawet przed wejściem do Hall of Fame,
  i można nim pływać za pomocą biletu S.S.
- Pociąg magnetyczny między Goldenrod a Saffron jest dostępny do jazdy z przepustką przed przywróceniem zasilania w
  Kanto
- Misty jest zawsze w Cerulean Gym
- Półka na Route 45 została przesunięta, aby wszystkie przedmioty i trenerzy byli dostępni w 2 przejściach
- W przypadku opcji, które to umożliwiają, odznaki Kanto odpowiadają następującym HM:
    - HM01 Cut - Cascade Badge
    - HM02 Fly - Thunder Badge
    - HM03 Surf - Soul Badge
    - HM04 Strength - Rainbow Badge
    - HM05 Flash - Boulder Badge
    - HM06 Whirlpool - Odznaka Volcano
    - HM07 Waterfall - Odznaka Earth
- TM02 i TM08 będą zawsze odpowiednio Headbutt i Rock Smash i zawsze będą wielokrotnego użytku.
- Ewolucje wymiany zostały zmienione, aby były możliwe w trybie solo:
    - Zwykłe ewolucje wymiany następują teraz na poziomie 37.
    - Ewolucje wymiany przedmiotów ewoluują, gdy użyje się na nich przedmiotu ewolucji, tak jak w przypadku kamienia
      ewolucji.
- Eevee ewoluuje w Espeona i Umbreona odpowiednio za pomocą kamienia słońca i kamienia księżyca.
- Ewolucje szczęścia są logicznie powiązane z dostępem do podziemi Goldenrod lub Pallet Town. Młodszy brat o krótkiej
  fryzurze i Daisy maksymalizują poziom szczęścia pokemona i są zawsze dostępni.
- Po zdobyciu Clear Bell można wejść na 1. piętro Tin Tower.
- Tin Tower 2F+ jest dostępna po spełnieniu powyższego warunku i posiadaniu Rainbow Wing. Oba są przedmiotami w
  multiworld.
- Eusine przekaże graczowi wiadomość Eon Mail, jeśli porozmawia z nim na 1. piętrze wieży Tin Tower po zobaczeniu
  Suicune w świecie gry we wszystkich możliwych lokalizacjach, które można odwiedzać w dowolnej kolejności
- Wydarzenie Celebi można aktywować, przekazując Kurtowi przedmiot wieloświatowy GS-Ball po ukończeniu Slowpoke Well i
  pokonaniu rywala w Azalea.
- Wydarzenie, które zazwyczaj zapewnia GS Ball w Goldenrod Pokécenter 1F, aktywuje się po zdobyciu tytułu mistrza.
- Dostęp do komnaty z przedmiotami Ruins of Alph Ho-Oh można uzyskać, posiadając skrzydło Rainbow Wing
- Do 2F wszystkich centrów Pokémon dodano sklep, którego asortyment można dostosować za pomocą opcji `build_a_mart`.
  Sklep zawsze będzie sprzedawał Poké Balls i Escape Ropes
- Na drugim piętrze wszystkich centrów Pokémon dodano postać NPC, która pozwala walczyć z losowym dzikim Pokémonem.
  Walka ta zapewnia
  pieniądze i doświadczenie, ale nie zapewnia wpisów do Pokédexu i nie można złapać pokemona.

## Jakie przedmioty i lokalizacje są losowane?

Domyślnie losowane są przedmioty z kul przedmiotów i przedmioty przekazywane przez NPC.
Odznaki mogą być standardowe, przetasowane lub losowe. Pokégear i jego moduły kart mogą być standardowe lub losowe.
Jeśli włączony jest tryb Johto Only, przedmioty w Kanto nie będą losowane, a Kanto będzie niedostępne.

Istnieją opcje umożliwiające dodanie większej liczby przedmiotów do puli:

- Losowe ukryte przedmioty: dodaje ukryte przedmioty do puli
- Losowe drzewa jagodowe: dodaje przedmioty z drzew jagodowych do puli
- Szaleństwo trenerów: dodaje do puli nagrodę za pokonanie trenerów
- Dexsanity: wpis Pokémona w Dexie może zawierać czek. Jest to powiązane z konkretnym Pokémonem
- Dexcountsanity: pewna liczba wpisów w Dexie zawiera czeki. Nie jest to powiązane z konkretnym Pokémonem, ale z
  całkowitą liczbą
- Shopsanity: dodaje przedmioty ze sklepu do puli

## Jakie inne zmiany wprowadzono do gry?

Wprowadzono wiele dodatkowych zmian poprawiających komfort gry:

- Do menu opcji w grze dodano nową opcję szybkości tekstu, Instant.
- Przyciski A i/lub B mogą służyć jako przyciski turbo, umożliwiające przyspieszenie dialogów.
- Gdy sceny bitewne są wyłączone, animacje zmniejszenia HP i zdobycia XP są pomijane
- Opcja Battle Scene jest bardziej szczegółowa, a najszybszy wybór, Speedy, eliminuje prawie wszystkie animacje.
- Możesz przytrzymać przycisk B, aby biec. Dostępna jest również opcja Auto-run, a jeśli jest włączona, przycisk B
  uniemożliwia bieganie.
- Dodano wiele innych opcji, które znacznie przyspieszają rozgrywkę, w tym: Rods mogą zawsze działać, niezłapane
  pokemony mogą pojawiać się częściej, trenerzy mogą być ślepi itp.
- Usunięto opóźnienia w menu
- Rower można używać w pomieszczeniach
- Jeśli skończy się repelent, a masz więcej w plecaku, pojawi się monit o użycie kolejnego.
- Tempo wzrostu pokemonów zostało znormalizowane (średnio-szybkie dla pokemonów niebędących legendarnymi, wolne dla
  pokemonów legendarnych).
- Usunięto system resetowania zegara za pomocą hasła. Zegar można zresetować, naciskając przyciski Down + Select + B na
  ekranie tytułowym.
- Dodano opcję w grze, dzięki której nie trzeba uczyć się ruchów terenowych. Aby zachować dostępność ruchów Fly, Flash i
  innych ruchów terenowych, po naciśnięciu przycisku Select w menu Start dostępne jest dodatkowe menu.
- Możesz odnowić wszystkie statyczne wydarzenia, rozmawiając z osobą odpowiedzialną za kapsułę czasu na drugim piętrze
  dowolnego PokéCenter
- Możesz teleportować się z powrotem do miasta startowego, wybierając opcję „Go Home” w menu głównym przed załadowaniem
  świata gry

## Jak wygląda przedmiot z innego świata w Pokémon Crystal?

Przedmioty z innych światów będą drukować nazwę przedmiotu i nazwę gracza, który go otrzymał, po zebraniu. Ze względu na
ograniczenia tekstu w grze nazwy te są skracane do 16 znaków, a znaki specjalne, których nie ma w
czcionce, są zastępowane znakami zapytania.

## Co się dzieje, gdy gracz otrzymuje przedmiot?

Jeśli opcja „Dźwięk otrzymania przedmiotu” jest włączona, po otrzymaniu przedmiotu zostanie odtworzony efekt dźwiękowy.
Aby odróżnić przedmioty związane z postępami w grze od pułapek, odtwarzane są różne dźwięki.

## Czy mogę grać w trybie offline?

Tak, gra nie wymaga połączenia z klientem w przypadku nasion solo. Połączenie jest wymagane tylko do wysyłania i
odbierania przedmiotów. Nie dotyczy to sytuacji, gdy włączona jest opcja `remote_items`.
